/********************************** <lalVerbatim file="StochasticInitSearchHV">
Author: Anderson, W.G., Romano, J.D., and Whelan, J.T.
$Id: StochasticInitSearch.h,v 1.19 2002/06/14 19:07:08 whelan Exp $
**************************************************** </lalVerbatim> */

/******************************* <lalLaTeX file="StochasticInitSearchH">
\section{Header \texttt{StochasticInitSearch.h}}
\label{s:StochasticInitSearch.h}

Header file for a routine that checks the validity of the input 
parameters, initializes them, and then allocates memory for certain
data structures used in the stochastic search.

\subsection*{Synopsis}
\begin{verbatim}
#include "StochasticInitSearch.h"
\end{verbatim}

\subsection*{Error conditions}
\input{StochasticInitSearchHErrTab}

\subsection*{Structures}

None.

*************************************************** </lalLaTeX> */

#ifndef _STOCHASTICINITSEARCH_H
#define _STOCHASTICINITSEARCH_H

#include <lal/LALStdlib.h>
#include "LALWrapperInterface.h"
#include "Stochastic.h"

#ifdef  __cplusplus
extern "C" {
#endif

NRCSID (STOCHASTICINITSEARCHH, "$Id: StochasticInitSearch.h,v 1.19 2002/06/14 19:07:08 whelan Exp $");

/******** <lalErrTable file="StochasticInitSearchHErrTab"> ********/
#define STOCHASTICINITSEARCHH_ENULL        1
#define STOCHASTICINITSEARCHH_ENNUL        2
#define STOCHASTICINITSEARCHH_EALOC        3
#define STOCHASTICINITSEARCHH_EARGS        4
#define STOCHASTICINITSEARCHH_EARG0        5
#define STOCHASTICINITSEARCHH_ENSEG        6
#define STOCHASTICINITSEARCHH_ENPTS        7
#define STOCHASTICINITSEARCHH_EBASE        8
#define STOCHASTICINITSEARCHH_EUWIN        9
#define STOCHASTICINITSEARCHH_ENWIN       10
#define STOCHASTICINITSEARCHH_ENFRQ       11
#define STOCHASTICINITSEARCHH_EF0         12
#define STOCHASTICINITSEARCHH_EDELF       13
#define STOCHASTICINITSEARCHH_EDTSZ       14
#define STOCHASTICINITSEARCHH_EFRES       15
#define STOCHASTICINITSEARCHH_EFRNG       16
#define STOCHASTICINITSEARCHH_EFNUM       17

#define STOCHASTICINITSEARCHH_MSGENULL    "Null pointer"
#define STOCHASTICINITSEARCHH_MSGENNUL    "Non-null pointer"
#define STOCHASTICINITSEARCHH_MSGEALOC    "Memory allocation error"
#define STOCHASTICINITSEARCHH_MSGEARGS    "Wrong number of arguments"
#define STOCHASTICINITSEARCHH_MSGEARG0    "Wrong value for argv[0]"
#define STOCHASTICINITSEARCHH_MSGENSEG    "Number of data segments is zero or negative"
#define STOCHASTICINITSEARCHH_MSGENPTS    "Number of points in a data segment is zero or negative"
#define STOCHASTICINITSEARCHH_MSGEBASE    "Heterodyning base frequency is negative"
#define STOCHASTICINITSEARCHH_MSGEUWIN    "Unknown window type"
#define STOCHASTICINITSEARCHH_MSGENWIN    "Flat top longer than window"
#define STOCHASTICINITSEARCHH_MSGENFRQ    "Number of frequencies is zero or negative"
#define STOCHASTICINITSEARCHH_MSGEF0      "Start frequency is negative"
#define STOCHASTICINITSEARCHH_MSGEDELF    "Frequency spacing is zero or negative"
#define STOCHASTICINITSEARCHH_MSGEDTSZ    "Nonstandard size of COMPLEX8 and/or UCHAR"
#define STOCHASTICINITSEARCHH_MSGEFRES    "Frequency sampling for output finer than for optimal filter"
#define STOCHASTICINITSEARCHH_MSGEFRNG    "Frequency range for output not fully contained in  optimal filter"
#define STOCHASTICINITSEARCHH_MSGEFNUM    "Number of frequencies in optimal filter is greater than number of data elements"

/******** </lalErrTable> ********/

/*
 * libstochastic.so should be invoked with the following arguments to wrapperAPI
 *
 * libldasstochastic.so should be invoked with the following arguments
 *
 * argv[1]  = numSegments       Number of data segments
 * argv[2]  = numPoints         Number of points in a data segment
 * argv[3]  = baseFreq          Hetrodyning base frequency of time series data
 * argv[4]  = windowType1       Index of window type (0=rect, 1=Hann, etc)
 * argv[5]  = windowTop1        Width of flat top in middle of window
 * argv[6]  = windowType2       Index of window type (0=rect, 1=Hann, etc)
 * argv[7]  = windowTop2        Width of flat top in middle of window
 * argv[8]  = fullLength        Length after zero-padding
 * argv[9]  = numFrequencies    Number of frequencies in optimal filter
 * argv[10] = f0                Start frequency for optimal filter
 * argv[11] = deltaF            Frequency spacing for optimal filter
 * argv[12] = outputNumFreq     Number of frequencies in CC spectrum
 * argv[13] = outputF0          Start frequency for CC spectrum
 * argv[14] = outputDeltaF      Frequency spacing for CC spectrum
 * argv[15] = epochsMatch       Check that time streams are simultaneous
 * argv[16] = siteID1           Identifier for first detector geometry
 * argv[17] = siteID2           Identifier for second detector geometry
 * argv[18] = outputType        Bitmask for DSO outputs 
 *
 */

typedef enum {
  STOCHASTICFILTERPARAM_FILTERPARAMS,
  STOCHASTICFILTERPARAM_NUMSEGMENTS,
  STOCHASTICFILTERPARAM_NUMPOINTS,
  STOCHASTICFILTERPARAM_BASEFREQ,
  STOCHASTICFILTERPARAM_WINDOWTYPE1,
  STOCHASTICFILTERPARAM_WINDOWTOP1, 
  STOCHASTICFILTERPARAM_WINDOWTYPE2,
  STOCHASTICFILTERPARAM_WINDOWTOP2,
  STOCHASTICFILTERPARAM_FULLLENGTH,
  STOCHASTICFILTERPARAM_NUMFREQUENCIES,
  STOCHASTICFILTERPARAM_F0,
  STOCHASTICFILTERPARAM_DELTAF,
  STOCHASTICFILTERPARAM_OUTPUTNUMFREQ,
  STOCHASTICFILTERPARAM_OUTPUTF0,
  STOCHASTICFILTERPARAM_OUTPUTDELTAF,
  STOCHASTICFILTERPARAM_EPOCHSMATCH,
  STOCHASTICFILTERPARAM_SITEID1,
  STOCHASTICFILTERPARAM_SITEID2,
  STOCHASTICFILTERPARAM_OUTPUTTYPE,
  STOCHASTICFILTERPARAM_NPARAMS
}
StochasticFilterParam;

#ifdef  __cplusplus
}
#endif /* C++ protection */

#endif /* _STOCHASTICINITSEARCH_H  */


/******************************* <lalLaTeX file="StochasticInitSearchH">
  
\vfill{\footnotesize\input{StochasticInitSearchHV}}

\newpage\input{StochasticInitSearchC}

*************************************************** </lalLaTeX> */
